@@ -4,6 +4,7 @@
 """Contains calculation of various derived indices."""
 import numpy as np
 
+from .basic import wind_speed
 from .thermo import mixing_ratio, saturation_vapor_pressure
 from .tools import _remove_nans, get_layer
 from .. import constants as mpconsts
@@ -99,7 +100,16 @@ def precipitable_water(pressure, dewpoint, *, bottom=None, top=None):
 def mean_pressure_weighted(pressure, *args, height=None, bottom=None, depth=None):
     r"""Calculate pressure-weighted mean of an arbitrary variable through a layer.
 
-    Layer top and bottom specified in height or pressure.
+    Layer bottom and depth specified in height or pressure.
+
+    .. math::  MPW = \frac{\int_{p_s}^{p_b} A p dp}{\int_{p_s}^{p_b} p dp}
+
+    where:
+
+    * :math:`MPW` is the pressure-weighted mean of a variable.
+    * :math:`p_b` is the bottom pressure level.
+    * :math:`p_s` is the top pressure level.
+    * :math:`A` is the variable whose pressure-weighted mean is being calculated.
 
     Parameters
     ----------
@@ -120,7 +130,7 @@ def mean_pressure_weighted(pressure, *args, height=None, bottom=None, depth=None
         assumed to be the surface.
 
     depth: `pint.Quantity`, optional
-        Depth of the layer in meters or hPa.
+        Depth of the layer in meters or hPa. Defaults to 100 hPa.
 
     Returns
     -------
@@ -169,12 +179,14 @@ def weighted_continuous_average(pressure, *args, height=None, bottom=None, depth
 
     Layer top and bottom specified in height or pressure.
 
-    Formula based on that from [Holton2004]_ pg. 76 and the NCL function _wgt_vertical_n_
+    Formula based on that from [Holton2004]_ pg. 76 and the NCL function ``wgt_vertical_n``
 
-    .. math::  WCA = \frac{\int_{p_s}^{p} A dp}{\int_{p_s}^{p} dp},
+    .. math::  WCA = \frac{\int_{p_s}^{p_b} A dp}{\int_{p_s}^{p_b} dp}
+
+    where:
 
     * :math:`WCA` is the weighted continuous average of a variable.
-    * :math:`p` is the bottom pressure level.
+    * :math:`p_b` is the bottom pressure level.
     * :math:`p_s` is the top pressure level.
     * :math:`A` is the variable whose weighted continuous average is being calculated.
 
@@ -273,9 +285,9 @@ def bunkers_storm_motion(pressure, u, v, height):
     >>> sped = [5, 15, 20, 30, 50, 60] * units.knots
     >>> u, v = wind_components(sped, wdir)
     >>> bunkers_storm_motion(p, u, v, h)
-    (<Quantity([22.73539654 10.27331352], 'knot')>,
-    <Quantity([ 7.27954821 34.99751866], 'knot')>,
-    <Quantity([15.00747237 22.63541609], 'knot')>)
+    (<Quantity([22.09618172 12.43406736], 'knot')>,
+    <Quantity([ 6.02861839 36.76517865], 'knot')>,
+    <Quantity([14.06240005 24.599623  ], 'knot')>)
 
     Notes
     -----
@@ -287,21 +299,28 @@ def bunkers_storm_motion(pressure, u, v, height):
        Renamed ``heights`` parameter to ``height``
 
     """
+    # remove nans from input data
+    pressure, u, v, height = _remove_nans(pressure, u, v, height)
+
     # mean wind from sfc-6km
-    _, u_mean, v_mean = get_layer(pressure, u, v, height=height,
-                                  depth=units.Quantity(6000, 'meter'))
-    wind_mean = units.Quantity([np.mean(u_mean).m, np.mean(v_mean).m], u_mean.units)
+    wind_mean = weighted_continuous_average(pressure, u, v, height=height,
+                                            depth=units.Quantity(6000, 'meter'))
+
+    wind_mean = units.Quantity.from_list(wind_mean)
 
     # mean wind from sfc-500m
-    _, u_500m, v_500m = get_layer(pressure, u, v, height=height,
-                                  depth=units.Quantity(500, 'meter'))
-    wind_500m = units.Quantity([np.mean(u_500m).m, np.mean(v_500m).m], u_500m.units)
+    wind_500m = weighted_continuous_average(pressure, u, v, height=height,
+                                            depth=units.Quantity(500, 'meter'))
+
+    wind_500m = units.Quantity.from_list(wind_500m)
 
     # mean wind from 5.5-6km
-    _, u_5500m, v_5500m = get_layer(pressure, u, v, height=height,
-                                    depth=units.Quantity(500, 'meter'),
-                                    bottom=height[0] + units.Quantity(5500, 'meter'))
-    wind_5500m = units.Quantity([np.mean(u_5500m).m, np.mean(v_5500m).m], u_5500m.units)
+    wind_5500m = weighted_continuous_average(
+        pressure, u, v, height=height,
+        depth=units.Quantity(500, 'meter'),
+        bottom=height[0] + units.Quantity(5500, 'meter'))
+
+    wind_5500m = units.Quantity.from_list(wind_5500m)
 
     # Calculate the shear vector from sfc-500m to 5.5-6km
     shear = wind_5500m - wind_500m
@@ -309,7 +328,7 @@ def bunkers_storm_motion(pressure, u, v, height):
     # Take the cross product of the wind shear and k, and divide by the vector magnitude and
     # multiply by the deviation empirically calculated in Bunkers (2000) (7.5 m/s)
     shear_cross = concatenate([shear[1], -shear[0]])
-    shear_mag = units.Quantity(np.hypot(*(arg.magnitude for arg in shear)), shear.units)
+    shear_mag = np.hypot(*shear)
     rdev = shear_cross * (units.Quantity(7.5, 'm/s').to(u.units) / shear_mag)
 
     # Add the deviations to the layer average wind to get the RM motion
@@ -321,6 +340,124 @@ def bunkers_storm_motion(pressure, u, v, height):
     return right_mover, left_mover, wind_mean
 
 
+@exporter.export
+@preprocess_and_wrap()
+@check_units('[pressure]', '[speed]', '[speed]', u_llj='[speed]', v_llj='[speed]')
+def corfidi_storm_motion(pressure, u, v, *, u_llj=None, v_llj=None):
+    r"""Calculate upwind- and downwind-developing MCS storm motions using the Corfidi method.
+
+    Method described by ([Corfidi2003]_):
+
+    * Cloud-layer winds, estimated as the mean of the wind from 850 hPa to 300 hPa
+    * Convergence along the cold pool, defined as the negative of the low-level jet
+        (estimated as maximum in winds below 850 hPa unless specified in u_llj and v_llj)
+    * The vector sum of the above is used to describe upwind propagating MCSes
+    * Downwind propagating MCSes are taken as propagating along the sum of the cloud-layer wind
+        and negative of the low level jet, therefore the cloud-level winds are doubled
+        to re-add storm motion
+
+    Parameters
+    ----------
+    pressure : `pint.Quantity`
+        Pressure from full profile
+
+    u : `pint.Quantity`
+        Full profile of the U-component of the wind
+
+    v : `pint.Quantity`
+        Full profile of the V-component of the wind
+
+    u_llj : `pint.Quantity`, optional
+        U-component of low-level jet
+
+    v_llj : `pint.Quantity`, optional
+        V-component of low-level jet
+
+    Returns
+    -------
+    upwind_prop: (`pint.Quantity`, `pint.Quantity`)
+        Scalar U- and V- components of Corfidi upwind propagating MCS motion
+
+    downwind_prop: (`pint.Quantity`, `pint.Quantity`)
+        Scalar U- and V- components of Corfidi downwind propagating MCS motion
+
+    Examples
+    --------
+    >>> from metpy.calc import corfidi_storm_motion, wind_components
+    >>> from metpy.units import units
+    >>> p = [1000, 925, 850, 700, 500, 400] * units.hPa
+    >>> wdir = [165, 180, 190, 210, 220, 250] * units.degree
+    >>> speed = [5, 15, 20, 30, 50, 60] * units.knots
+    >>> u, v = wind_components(speed, wdir)
+    >>> corfidi_storm_motion(p, u, v)
+    (<Quantity([16.4274315   7.75758388], 'knot')>,
+    <Quantity([36.32782655 35.21132283], 'knot')>)
+    >>> # Example with manually specified low-level jet as max wind below 1500m
+    >>> import numpy as np
+    >>> h = [100, 250, 700, 1500, 3100, 5720] * units.meters
+    >>> lowest1500_index = np.argmin(h <= units.Quantity(1500, 'meter'))
+    >>> llj_index = np.argmax(speed[:lowest1500_index])
+    >>> llj_u, llj_v = u[llj_index], v[llj_index]
+    >>> corfidi_storm_motion(p, u, v, u_llj=llj_u, v_llj=llj_v)
+    (<Quantity([4.90039505   1.47297683], 'knot')>,
+    <Quantity([24.8007901 28.92671577], 'knot')>)
+
+
+    Notes
+    -----
+    Only functions on 1D profiles (not higher-dimension vertical cross sections or grids).
+    Since this function returns scalar values when given a profile, this will return Pint
+    Quantities even when given xarray DataArray profiles.
+
+    """
+    # If user specifies only one component of low-level jet, raise
+    if (u_llj is None) ^ (v_llj is None):
+        raise ValueError('Must specify both u_llj and v_llj or neither')
+
+    # remove nans from input
+    pressure, u, v = _remove_nans(pressure, u, v)
+
+    # If LLJ specified, use that
+    if u_llj is not None and v_llj is not None:
+        # find inverse of low-level jet
+        llj_inverse = units.Quantity.from_list((-1 * u_llj, -1 * v_llj))
+    # If pressure values contain values below 850 hPa, find low-level jet
+    elif np.max(pressure) >= units.Quantity(850, 'hectopascal'):
+        # convert u/v wind to wind speed and direction
+        wind_magnitude = wind_speed(u, v)
+        # find inverse of low-level jet
+        lowlevel_index = np.argmin(pressure >= units.Quantity(850, 'hectopascal'))
+        llj_index = np.argmax(wind_magnitude[:lowlevel_index])
+        llj_inverse = units.Quantity.from_list((-u[llj_index], -v[llj_index]))
+    # If LLJ not specified and maximum pressure value is above 850 hPa, raise
+    else:
+        raise ValueError('Must specify low-level jet or '
+                         'specify pressure values below 850 hPa')
+
+    # cloud layer mean wind
+    # don't select outside bounds of given data
+    if pressure[0] < units.Quantity(850, 'hectopascal'):
+        bottom = pressure[0]
+    else:
+        bottom = units.Quantity(850, 'hectopascal')
+    if pressure[-1] > units.Quantity(300, 'hectopascal'):
+        depth = bottom - pressure[-1]
+    else:
+        depth = units.Quantity(550, 'hectopascal')
+    cloud_layer_winds = mean_pressure_weighted(pressure, u, v,
+                                               bottom=bottom,
+                                               depth=depth)
+
+    cloud_layer_winds = units.Quantity.from_list(cloud_layer_winds)
+
+    # calculate corfidi vectors
+    upwind = cloud_layer_winds + llj_inverse
+
+    downwind = 2 * cloud_layer_winds + llj_inverse
+
+    return upwind, downwind
+
+
 @exporter.export
 @preprocess_and_wrap()
 @check_units('[pressure]', '[speed]', '[speed]')
